<!doctype html>
<html lang="de">

<head>
  <!-- Required meta tags -->
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

  <title>{% block title %}{% endblock %} | Justic</title>
  <link rel="stylesheet" href="{{ SITEURL }}/static/css/bootstrap.min.css">
</head>

<body>
  {% include 'include/header.html' %}

  <div class="container">
    {% block content %}{% endblock %}
  </div>

  <footer class="footer">
    <div class="container">
      {% include 'include/footer.html' %}
    </div>
  </footer>
</body>

</html>
