<nav class="navbar navbar-expand-sm bg-light navbar-light">
  <ul class="navbar-nav">
    {% for item in NAVIBAR %}
    <li class="nav-item active">
      <a class="nav-link" href="{{SITEURL}}{{item.href}}">{{item.caption}}</a>
    </li>
    {% endfor %}
  </ul>
</nav>
